==> php-doctrine-bundle_1.11.2.orig.tar.gz: php-doctrine-bundle-1.11.2/Tests/Builder/BundleConfigurationBuilder.php <==
<?php

namespace Doctrine\Bundle\DoctrineBundle\Tests\Builder;

class BundleConfigurationBuilder
{
    /** @var array */
    private $configuration;

    public static function createBuilder()
    {
        return new self();
    }

    public static function createBuilderWithBaseValues()
    {
        $builder = new self();
        $builder->addBaseConnection();
        $builder->addBaseEntityManager();

        return $builder;
    }

    public function addBaseConnection()
    {
        $this->addConnection([
            'connections' => [
                'default' => ['password' => 'foo'],
            ],
        ]);

        return $this;
    }

    public function addBaseEntityManager()
    {
        $this->addEntityManager([
            'default_entity_manager' => 'default',
            'entity_managers' => [
                'default' => [
                    'mappings' => [
                        'YamlBundle' => [],
                    ],
                ],
            ],
        ]);

        return $this;
    }

    public function addBaseSecondLevelCache()
    {
        $this->addSecondLevelCache([
            'region_cache_driver' => ['type' => 'memcache'],
            'regions' => [
                'hour_region' => ['lifetime' => 3600],
            ],
        ]);

        return $this;
    }

    public function addConnection($config)
    {
        $this->configuration['dbal'] = $config;

        return $this;
    }

    public function addEntityManager($config)
    {
        $this->configuration['orm'] = $config;

        return $this;
    }

    public function addSecondLevelCache($config, $manager = 'default')
    {
        $this->configuration['orm']['entity_managers'][$manager]['second_level_cache'] = $config;

        return $this;
    }

    public function build()
    {
        return $this->configuration;
    }
}

==> php-doctrine-bundle_2.0.6.orig.tar.gz: php-doctrine-bundle-2.0.6/Tests/Builder/BundleConfigurationBuilder.php <==
<?php

namespace Doctrine\Bundle\DoctrineBundle\Tests\Builder;

class BundleConfigurationBuilder
{
    /** @var array */
    private $configuration;

    public static function createBuilder()
    {
        return new self();
    }

    public static function createBuilderWithBaseValues()
    {
        $builder = new self();
        $builder->addBaseConnection();
        $builder->addBaseEntityManager();

        return $builder;
    }

    public function addBaseConnection()
    {
        $this->addConnection([
            'connections' => [
                'default' => ['password' => 'foo'],
            ],
        ]);

        return $this;
    }

    public function addBaseEntityManager()
    {
        $this->addEntityManager([
            'default_entity_manager' => 'default',
            'entity_managers' => [
                'default' => [
                    'mappings' => [
                        'YamlBundle' => [],
                    ],
                ],
            ],
        ]);

        return $this;
    }

    public function addBaseSecondLevelCache()
    {
        $this->addSecondLevelCache([
            'region_cache_driver' => ['type' => 'pool', 'pool' => 'my_pool'],
            'regions' => [
                'hour_region' => ['lifetime' => 3600],
            ],
        ]);

        return $this;
    }

    public function addConnection($config)
    {
        $this->configuration['dbal'] = $config;

        return $this;
    }

    public function addEntityManager($config)
    {
        $this->configuration['orm'] = $config;

        return $this;
    }

    public function addSecondLevelCache($config, $manager = 'default')
    {
        $this->configuration['orm']['entity_managers'][$manager]['second_level_cache'] = $config;

        return $this;
    }

    public function build()
    {
        return $this->configuration;
    }
}
